// SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#pragma once

#include <QAbstractTableModel>
#include <QDir>
#include <QFutureWatcher>
#include <QImage>
#include <QJsonObject>
#include <QNetworkAccessManager>

class ArtPiece : public QObject
{
    Q_OBJECT
public:
    ArtPiece() = default;
    ArtPiece(const QString &path);

    QString filename, jsonFilename;
    QString title;
    QJsonObject object;

    QDate date;
    QImage thumbnail;

    bool hasAltText = false;

    QUrl getImagePath() const;
    QUrl getThumbnailPath() const;
};

class ArtModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    explicit ArtModel(const QDir &definitionDirectory, QObject *parent = nullptr);

    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
    [[nodiscard]] int columnCount(const QModelIndex &parent) const override;

    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
    [[nodiscard]] QVariant headerData(int section, Qt::Orientation orientation, int role) const override;

Q_SIGNALS:
    void loadingFinished();

protected:
    QVector<ArtPiece *> m_artPieces;

private:
    void pieceFinished(int index);
    void finished();

    QFutureWatcher<ArtPiece *> *piecesFuture;
};
