// SPDX-FileCopyrightText: 2024 Joshua Goins <josh@redstrate.com>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#pragma once

#include <QAbstractTableModel>
#include <QDir>
#include <QFutureWatcher>
#include <QImage>
#include <QJsonObject>
#include <QNetworkAccessManager>

class Character : public QObject
{
    Q_OBJECT
public:
    Character() = default;
    Character(const QString &filename);

    QString filename;
    QString name;
};

class CharacterModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    explicit CharacterModel(const QDir &definitionDirectory, QObject *parent = nullptr);

    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
    [[nodiscard]] int columnCount(const QModelIndex &parent) const override;

    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
    [[nodiscard]] QVariant headerData(int section, Qt::Orientation orientation, int role) const override;

Q_SIGNALS:
    void loadingFinished();

protected:
    QVector<Character *> m_characters;

private:
    void characterFinished(int index);
    void finished();

    QFutureWatcher<Character *> *charactersFuture;
};
