// SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include "featuredartmodel.h"

#include <QFileInfo>

FeaturedArtModel::FeaturedArtModel(const QString &definitionDirectory)
    : ArtModel(definitionDirectory)
{
}

QVariant FeaturedArtModel::data(const QModelIndex &index, int role) const
{
    if (!index.isValid())
        return {};

    if (role == Qt::DisplayRole) {
        if (index.column() == 0) {
            return ArtModel::data(FeaturedArtModel::index(index.row(), 2), role);
        } else {
            return ArtModel::data(FeaturedArtModel::index(index.row(), 0), role);
        }
    } else if (role == Qt::DecorationRole && index.column() == 0) {
        return ArtModel::data(FeaturedArtModel::index(index.row(), 1), role);
    } else if (role == Qt::CheckStateRole) {
        return checkedItems.contains(index) ? Qt::Checked : Qt::Unchecked;
    }

    return ArtModel::data(index, role);
}

Qt::ItemFlags FeaturedArtModel::flags(const QModelIndex &index) const
{
    const Qt::ItemFlags defaultFlags = ArtModel::flags(index);
    if (index.isValid()) {
        return defaultFlags | Qt::ItemIsUserCheckable;
    }

    return defaultFlags;
}

bool FeaturedArtModel::setData(const QModelIndex &index, const QVariant &value, int role)
{
    if (!index.isValid() || role != Qt::CheckStateRole) {
        return false;
    }

    if (value == Qt::Checked) {
        checkedItems.insert(index);
    } else {
        checkedItems.remove(index);
    }

    emit dataChanged(index, index);
    return true;
}

void FeaturedArtModel::setFeaturedItems(const QStringList &featured)
{
    for (const auto &id : featured) {
        for (int i = 0; i < m_artPieces.size(); i++) {
            auto &piece = m_artPieces[i];
            QFileInfo fileInfo(piece->jsonFilename);
            if (fileInfo.baseName() == id) {
                setData(index(i, 0), Qt::Checked, Qt::CheckStateRole);
            }
        }
    }
}
