// SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include <KAboutData>
#include <KLocalizedString>
#include <QApplication>
#include <QCommandLineParser>

#include "mainwindow.h"

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    KLocalizedString::setApplicationDomain("redai");

    KAboutData about(QStringLiteral("redai"),
                     i18n("Redai"),
                     QStringLiteral("1.0"),
                     i18n("Website gallery manager"),
                     KAboutLicense::GPL_V3,
                     i18n("© 2024 Joshua Goins"));
    about.addAuthor(i18n("Joshua Goins"), i18n("Maintainer"), QStringLiteral("josh@redstrate.com"), QStringLiteral("https://redstrate.com/"));
    about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));

    KAboutData::setApplicationData(about);

    QCommandLineParser parser;
    parser.addPositionalArgument(QStringLiteral("site-path"), i18nc("@info", "Site directory."));

    parser.process(app);

    const auto args = parser.positionalArguments();
    if (args.empty()) {
        return -1;
    }

    const QDir sitePath = args[0];
    const QDir dataPath = sitePath.absoluteFilePath(QStringLiteral("data"));
    const QString defPath = dataPath.absoluteFilePath(QStringLiteral("art"));
    const QString charaDefPath = dataPath.absoluteFilePath(QStringLiteral("characters"));

    MainWindow window(defPath, dataPath, charaDefPath);
    window.show();

    return QApplication::exec();
}
